@@ -250,23 +250,21 @@ public class CVSProjectSetCapability extends ProjectSetCapability {
 		
 		final List result = new ArrayList();
 		try {
-			ResourcesPlugin.getWorkspace().run(new IWorkspaceRunnable() {
-				public void run(IProgressMonitor monitor) throws CoreException {
-					monitor.beginTask("", 1000 * projects.length); //$NON-NLS-1$
-					try {
-						for (int i = 0; i < projects.length; i++) {
-							if (monitor.isCanceled())
-								break;
-							IProject project = projects[i];
-							LoadInfo info = (LoadInfo) infoMap.get(project);
-							if (info != null && info.checkout(SubMonitor.convert(monitor, 1000)))
-								result.add(project);
-						}
-					}
-					finally {
-						monitor.done();
+			ResourcesPlugin.getWorkspace().run((IWorkspaceRunnable) monitor1 -> {
+				monitor1.beginTask("", 1000 * projects.length); //$NON-NLS-1$
+				try {
+					for (int i = 0; i < projects.length; i++) {
+						if (monitor1.isCanceled())
+							break;
+						IProject project = projects[i];
+						LoadInfo info = (LoadInfo) infoMap.get(project);
+						if (info != null && info.checkout(SubMonitor.convert(monitor1, 1000)))
+							result.add(project);
 					}
 				}
+				finally {
+					monitor1.done();
+				}
 			}, getCheckoutRule(projects), IResource.NONE, monitor);
 		} catch (CoreException e) {
 			throw TeamException.asTeamException(e);
@@ -406,108 +404,104 @@ public class CVSProjectSetCapability extends ProjectSetCapability {
 	public static void checkout(final ICVSRemoteFolder[] resources, final IProject[] projects, final IProgressMonitor monitor) throws TeamException {
 		final TeamException[] eHolder = new TeamException[1];
 		try {
-			IWorkspaceRunnable workspaceRunnable = new IWorkspaceRunnable() {
-				public void run(IProgressMonitor pm) throws CoreException {
-					try {
-						pm.beginTask(null, 1000 * resources.length);
+			IWorkspaceRunnable workspaceRunnable = pm -> {
+				try {
+					pm.beginTask(null, 1000 * resources.length);
+					
+					// Get the location of the workspace root
+					ICVSFolder root = CVSWorkspaceRoot.getCVSFolderFor(ResourcesPlugin.getWorkspace().getRoot());
+					
+					for (int i=0;i<resources.length;i++) {
+						IProject project = null;
+						RemoteFolder resource = (RemoteFolder)resources[i];
 						
-						// Get the location of the workspace root
-						ICVSFolder root = CVSWorkspaceRoot.getCVSFolderFor(ResourcesPlugin.getWorkspace().getRoot());
+						// Determine the provided target project if there is one
+						if (projects != null) 
+							project = projects[i];
 						
-						for (int i=0;i<resources.length;i++) {
-							IProject project = null;
-							RemoteFolder resource = (RemoteFolder)resources[i];
+						// Determine the remote module to be checked out
+						String moduleName;
+						if (resource instanceof RemoteModule) {
+							moduleName = ((RemoteModule)resource).getName();
+						} else {
+							moduleName = resource.getRepositoryRelativePath();
+						}
+						
+						// Open a connection session to the repository
+						ICVSRepositoryLocation repository = resource.getRepository();
+						Session session = new Session(repository, root);
+						try {
+							session.open(Policy.subMonitorFor(pm, 50), false /* read-only */);
 							
-							// Determine the provided target project if there is one
-							if (projects != null) 
-								project = projects[i];
-							
-							// Determine the remote module to be checked out
-							String moduleName;
-							if (resource instanceof RemoteModule) {
-								moduleName = ((RemoteModule)resource).getName();
+							// Determine the local target projects (either the project provider or the module expansions) 
+							final Set targetProjects = new HashSet();
+							if (project == null) {
+								
+								// Fetch the module expansions
+								IStatus status1 = Request.EXPAND_MODULES.execute(session, new String[] {moduleName}, Policy.subMonitorFor(pm, 50));
+								if (status1.getCode() == CVSStatus.SERVER_ERROR) {
+									throw new CVSServerException(status1);
+								}
+								
+								// Convert the module expansions to local projects
+								String[] expansions = session.getModuleExpansions();
+								for (int j = 0; j < expansions.length; j++) {
+									targetProjects.add(ResourcesPlugin.getWorkspace().getRoot().getProject(new Path(null, expansions[j]).segment(0)));
+								}
+								
 							} else {
-								moduleName = resource.getRepositoryRelativePath();
+								targetProjects.add(project);
 							}
 							
-							// Open a connection session to the repository
-							ICVSRepositoryLocation repository = resource.getRepository();
-							Session session = new Session(repository, root);
-							try {
-								session.open(Policy.subMonitorFor(pm, 50), false /* read-only */);
-								
-								// Determine the local target projects (either the project provider or the module expansions) 
-								final Set targetProjects = new HashSet();
-								if (project == null) {
-									
-									// Fetch the module expansions
-									IStatus status = Request.EXPAND_MODULES.execute(session, new String[] {moduleName}, Policy.subMonitorFor(pm, 50));
-									if (status.getCode() == CVSStatus.SERVER_ERROR) {
-										throw new CVSServerException(status);
-									}
-									
-									// Convert the module expansions to local projects
-									String[] expansions = session.getModuleExpansions();
-									for (int j = 0; j < expansions.length; j++) {
-										targetProjects.add(ResourcesPlugin.getWorkspace().getRoot().getProject(new Path(null, expansions[j]).segment(0)));
-									}
-									
-								} else {
-									targetProjects.add(project);
-								}
-								
-								// Prepare the target projects to receive resources
-								root.run(new ICVSRunnable() {
-									public void run(IProgressMonitor monitor) throws CVSException {
-										scrubProjects((IProject[]) targetProjects.toArray(new IProject[targetProjects.size()]), monitor);
-									}
-								}, Policy.subMonitorFor(pm, 100));
-							
-								// Build the local options
-								List localOptions = new ArrayList();
-								// Add the option to load into the target project if one was supplied
-								if (project != null) {
-									localOptions.add(Checkout.makeDirectoryNameOption(project.getName()));
-								}
-								// Prune empty directories if pruning enabled
-								if (CVSProviderPlugin.getPlugin().getPruneEmptyDirectories()) 
-									localOptions.add(Command.PRUNE_EMPTY_DIRECTORIES);
-								// Add the options related to the CVSTag
-								CVSTag tag = resource.getTag();
-								if (tag == null) {
-									// A null tag in a remote resource indicates HEAD
-									tag = CVSTag.DEFAULT;
-								}
-								localOptions.add(Update.makeTagOption(tag));
-		
-								// Perform the checkout
-								IStatus status = Command.CHECKOUT.execute(session,
-									Command.NO_GLOBAL_OPTIONS,
-									(LocalOption[])localOptions.toArray(new LocalOption[localOptions.size()]),
-									new String[]{moduleName},
-									null,
-									Policy.subMonitorFor(pm, 800));
-								if (status.getCode() == CVSStatus.SERVER_ERROR) {
-									// XXX Should we cleanup any partially checked out projects?
-									throw new CVSServerException(status);
-								}
-								
-								// Bring the project into the workspace
-								refreshProjects((IProject[])targetProjects.toArray(new IProject[targetProjects.size()]), Policy.subMonitorFor(pm, 100));
+							// Prepare the target projects to receive resources
+							root.run(monitor1 -> scrubProjects(
+									(IProject[]) targetProjects.toArray(new IProject[targetProjects.size()]), monitor1),
+									Policy.subMonitorFor(pm, 100));
 
-							} finally {
-								session.close();
+							// Build the local options
+							List localOptions = new ArrayList();
+							// Add the option to load into the target project if one was supplied
+							if (project != null) {
+								localOptions.add(Checkout.makeDirectoryNameOption(project.getName()));
 							}
+							// Prune empty directories if pruning enabled
+							if (CVSProviderPlugin.getPlugin().getPruneEmptyDirectories()) 
+								localOptions.add(Command.PRUNE_EMPTY_DIRECTORIES);
+							// Add the options related to the CVSTag
+							CVSTag tag = resource.getTag();
+							if (tag == null) {
+								// A null tag in a remote resource indicates HEAD
+								tag = CVSTag.DEFAULT;
+							}
+							localOptions.add(Update.makeTagOption(tag));
+
+							// Perform the checkout
+							IStatus status2 = Command.CHECKOUT.execute(session,
+								Command.NO_GLOBAL_OPTIONS,
+								(LocalOption[])localOptions.toArray(new LocalOption[localOptions.size()]),
+								new String[]{moduleName},
+								null,
+								Policy.subMonitorFor(pm, 800));
+							if (status2.getCode() == CVSStatus.SERVER_ERROR) {
+								// XXX Should we cleanup any partially checked out projects?
+								throw new CVSServerException(status2);
+							}
+							
+							// Bring the project into the workspace
+							refreshProjects((IProject[])targetProjects.toArray(new IProject[targetProjects.size()]), Policy.subMonitorFor(pm, 100));
+
+						} finally {
+							session.close();
 						}
 					}
-					catch (TeamException e) {
-						// Pass it outside the workspace runnable
-						eHolder[0] = e;
-					} finally {
-						pm.done();
-					}
-					// CoreException and OperationCanceledException are propagated
 				}
+				catch (TeamException e) {
+					// Pass it outside the workspace runnable
+					eHolder[0] = e;
+				} finally {
+					pm.done();
+				}
+				// CoreException and OperationCanceledException are propagated
 			};
 			ResourcesPlugin.getWorkspace().run(workspaceRunnable, getCheckoutRule(projects), 0, monitor);
 		} catch (CoreException e) {
