@@ -24,15 +24,14 @@ import java.util.*;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.jface.action.*;
 import org.eclipse.jface.commands.ActionHandler;
-import org.eclipse.jface.dialogs.*;
 import org.eclipse.jface.dialogs.Dialog;
+import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.dialogs.MessageDialogWithToggle;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.text.*;
 import org.eclipse.jface.text.contentassist.ICompletionProposal;
 import org.eclipse.jface.text.source.*;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyledText;
 import org.eclipse.swt.events.*;
@@ -89,7 +88,7 @@ public class CommitCommentArea extends DialogArea {
     		
             support.install(EditorsUI.getPreferenceStore());
             
-            final IHandlerService handlerService = (IHandlerService)PlatformUI.getWorkbench().getService(IHandlerService.class);
+            final IHandlerService handlerService = PlatformUI.getWorkbench().getService(IHandlerService.class);
             final IHandlerActivation handlerActivation = installQuickFixActionHandler(handlerService, sourceViewer);
             
             final TextViewerAction cutAction = new TextViewerAction(sourceViewer, ITextOperationTarget.CUT);
@@ -117,43 +116,50 @@ public class CommitCommentArea extends DialogArea {
             
             final SubMenuManager quickFixMenu = new SubMenuManager(contextMenu);
             quickFixMenu.setVisible(true);
-            quickFixMenu.addMenuListener(new IMenuListener() {
-			
-				public void menuAboutToShow(IMenuManager manager) {
-					quickFixMenu.removeAll();
-					
-            		IAnnotationModel annotationModel = sourceViewer.getAnnotationModel();
-            		Iterator annotationIterator = annotationModel.getAnnotationIterator();
-            		while (annotationIterator.hasNext()) {
-            			Annotation annotation = (Annotation) annotationIterator.next();
-            			if (!annotation.isMarkedDeleted() && includes(annotationModel.getPosition(annotation), sourceViewer.getTextWidget().getCaretOffset()) && sourceViewer.getQuickAssistAssistant().canFix(annotation)) {
-            				ICompletionProposal[] computeQuickAssistProposals = sourceViewer.getQuickAssistAssistant().getQuickAssistProcessor().computeQuickAssistProposals(sourceViewer.getQuickAssistInvocationContext());
-            				for (int i = 0; i < computeQuickAssistProposals.length; i++) {
-            					final ICompletionProposal proposal = computeQuickAssistProposals[i];
-            					quickFixMenu.add(new Action(proposal.getDisplayString()) {
-            						
-            						/* (non-Javadoc)
-            						 * @see org.eclipse.jface.action.Action#run()
-            						 */
-            						public void run() {
-            							proposal.apply(sourceViewer.getDocument());
-            						}
-            						
-            						/* (non-Javadoc)
-            						 * @see org.eclipse.jface.action.Action#getImageDescriptor()
-            						 */
-            						public ImageDescriptor getImageDescriptor() {
-            							if (proposal.getImage() != null) {
-            								return ImageDescriptor.createFromImage(proposal.getImage());
-            							}
-            							return null;
-            						}
-            					});
-            				}
-            			}
-            		}
+			quickFixMenu.addMenuListener(manager -> {
+				quickFixMenu.removeAll();
+
+				IAnnotationModel annotationModel1 = sourceViewer.getAnnotationModel();
+				Iterator annotationIterator = annotationModel1.getAnnotationIterator();
+				while (annotationIterator.hasNext()) {
+					Annotation annotation = (Annotation) annotationIterator.next();
+					if (!annotation.isMarkedDeleted()
+							&& includes(annotationModel1.getPosition(annotation),
+									sourceViewer.getTextWidget().getCaretOffset())
+							&& sourceViewer.getQuickAssistAssistant().canFix(annotation)) {
+						ICompletionProposal[] computeQuickAssistProposals = sourceViewer.getQuickAssistAssistant()
+								.getQuickAssistProcessor()
+								.computeQuickAssistProposals(sourceViewer.getQuickAssistInvocationContext());
+						for (int i = 0; i < computeQuickAssistProposals.length; i++) {
+							final ICompletionProposal proposal = computeQuickAssistProposals[i];
+							quickFixMenu.add(new Action(proposal.getDisplayString()) {
+
+								/*
+								 * (non-Javadoc)
+								 * 
+								 * @see org.eclipse.jface.action.Action#run()
+								 */
+								@Override
+								public void run() {
+									proposal.apply(sourceViewer.getDocument());
+								}
+
+								/*
+								 * (non-Javadoc)
+								 * 
+								 * @see org.eclipse.jface.action.Action#getImageDescriptor()
+								 */
+								@Override
+								public ImageDescriptor getImageDescriptor() {
+									if (proposal.getImage() != null) {
+										return ImageDescriptor.createFromImage(proposal.getImage());
+									}
+									return null;
+								}
+							});
+						}
+					}
 				}
-			
 			});
             
             fTextField.addFocusListener(new FocusListener() {
@@ -163,10 +169,11 @@ public class CommitCommentArea extends DialogArea {
 				private IHandlerActivation pasteHandlerActivation;
 				private IHandlerActivation selectAllHandlerActivation;
 
+				@Override
 				public void focusGained(FocusEvent e) {
 					cutAction.update();
 					copyAction.update();
-					IHandlerService service = (IHandlerService) PlatformUI.getWorkbench().getService(IHandlerService.class);
+					IHandlerService service = PlatformUI.getWorkbench().getService(IHandlerService.class);
 					this.cutHandlerActivation = service.activateHandler(IWorkbenchCommandConstants.EDIT_CUT, new ActionHandler(cutAction), new ActiveShellExpression(getComposite().getShell()));
 		            this.copyHandlerActivation = service.activateHandler(IWorkbenchCommandConstants.EDIT_COPY, new ActionHandler(copyAction), new ActiveShellExpression(getComposite().getShell()));
 		            this.pasteHandlerActivation = service.activateHandler(IWorkbenchCommandConstants.EDIT_PASTE, new ActionHandler(pasteAction), new ActiveShellExpression(getComposite().getShell()));
@@ -178,8 +185,9 @@ public class CommitCommentArea extends DialogArea {
 				/* (non-Javadoc)
 				 * @see org.eclipse.swt.events.FocusAdapter#focusLost(org.eclipse.swt.events.FocusEvent)
 				 */
+				@Override
 				public void focusLost(FocusEvent e) {
-					IHandlerService service = (IHandlerService) PlatformUI.getWorkbench().getService(IHandlerService.class);
+					IHandlerService service = PlatformUI.getWorkbench().getService(IHandlerService.class);
 					
 					if (cutHandlerActivation != null) {
 						service.deactivateHandler(cutHandlerActivation);
@@ -200,22 +208,14 @@ public class CommitCommentArea extends DialogArea {
 			
 			});
             
-            sourceViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-            	
-            	public void selectionChanged(SelectionChangedEvent event) {
-            		cutAction.update();
-            		copyAction.update();
-            	}
-            	
-            });
+			sourceViewer.addSelectionChangedListener(event -> {
+				cutAction.update();
+				copyAction.update();
+			});
             
-            sourceViewer.getTextWidget().addDisposeListener(new DisposeListener() {
-			
-				public void widgetDisposed(DisposeEvent e) {
-					support.uninstall();
-					handlerService.deactivateHandler(handlerActivation);
-				}
-			
+			sourceViewer.getTextWidget().addDisposeListener(e1 -> {
+				support.uninstall();
+				handlerService.deactivateHandler(handlerActivation);
 			});
             
             fDocument = new Document(initialText);
@@ -264,7 +264,8 @@ public class CommitCommentArea extends DialogArea {
             	/* (non-Javadoc)
             	 * @see org.eclipse.jface.action.Action#run()
             	 */
-            	public void run() {
+            	@Override
+				public void run() {
             		textOperationTarget.doOperation(ISourceViewer.QUICK_ASSIST);
             	}
             };
@@ -272,21 +273,24 @@ public class CommitCommentArea extends DialogArea {
     		return new ActionHandler(quickFixAction);
         }
 
-        public void modifyText(ModifyEvent e) {
+        @Override
+		public void modifyText(ModifyEvent e) {
             final String old = fText;
             fText = fTextField.getText();
             if (!fText.equals(old))
             	firePropertyChangeChange(COMMENT_MODIFIED, old, fText);
         }
         
-        public void keyTraversed(TraverseEvent e) {
+        @Override
+		public void keyTraversed(TraverseEvent e) {
             if (e.detail == SWT.TRAVERSE_RETURN && (e.stateMask & SWT.CTRL) != 0) {
                 e.doit = false;
                 firePropertyChangeChange(OK_REQUESTED, null, null);
             }
         }
         
-        public void focusGained(FocusEvent e) {
+        @Override
+		public void focusGained(FocusEvent e) {
 
             if (fText.length() > 0)
                 return;
@@ -301,7 +305,8 @@ public class CommitCommentArea extends DialogArea {
             }
         }
         
-        public void focusLost(FocusEvent e) {
+        @Override
+		public void focusLost(FocusEvent e) {
             
             if (fText.length() > 0)
                 return;
@@ -321,7 +326,8 @@ public class CommitCommentArea extends DialogArea {
             fTextField.setEnabled(enabled);
         }
         
-        public void update(Observable o, Object arg) {
+        @Override
+		public void update(Observable o, Object arg) {
             if (arg instanceof String) {
                 setText((String)arg); // triggers a modify event
             }
@@ -343,10 +349,12 @@ public class CommitCommentArea extends DialogArea {
             fTextField.setFocus();
         }
 
-        public void documentAboutToBeChanged(DocumentEvent event) {
+        @Override
+		public void documentAboutToBeChanged(DocumentEvent event) {
         }
 
-        public void documentChanged(DocumentEvent event) {
+        @Override
+		public void documentChanged(DocumentEvent event) {
         	modifyText(null);
         }
 	}
@@ -393,7 +401,8 @@ public class CommitCommentArea extends DialogArea {
             fCombo.setText(fMessage);
 		}
         
-        public void widgetSelected(SelectionEvent e) {
+        @Override
+		public void widgetSelected(SelectionEvent e) {
             int index = fCombo.getSelectionIndex();
             if (index > 0) {
                 index--;
@@ -410,16 +419,19 @@ public class CommitCommentArea extends DialogArea {
             }
         }
         
-        public void widgetDefaultSelected(SelectionEvent e) {
+        @Override
+		public void widgetDefaultSelected(SelectionEvent e) {
         }
         
-        public void focusGained(FocusEvent e) {
+        @Override
+		public void focusGained(FocusEvent e) {
         }
         
         /* (non-Javadoc)
          * @see org.eclipse.swt.events.FocusListener#focusLost(org.eclipse.swt.events.FocusEvent)
          */
-        public void focusLost(FocusEvent e) {
+        @Override
+		public void focusLost(FocusEvent e) {
             fCombo.removeSelectionListener(this);
             try {
                 fCombo.setText(fMessage);
@@ -455,7 +467,8 @@ public class CommitCommentArea extends DialogArea {
     /**
      * @see org.eclipse.team.internal.ccvs.ui.DialogArea#createArea(org.eclipse.swt.widgets.Composite)
      */
-    public void createArea(Composite parent) {
+    @Override
+	public void createArea(Composite parent) {
         Dialog.applyDialogFont(parent);
         initializeDialogUnits(parent);
         
@@ -472,10 +485,12 @@ public class CommitCommentArea extends DialogArea {
         templatesPrefsLink.setText("<a href=\"configureTemplates\">" + //$NON-NLS-1$
         		CONFIGURE_TEMPLATES_MESSAGE + "</a>"); //$NON-NLS-1$
         templatesPrefsLink.addSelectionListener(new SelectionListener() {
+			@Override
 			public void widgetDefaultSelected(SelectionEvent e) {
 				openCommentTemplatesPreferencePage();
 			}
 		
+			@Override
 			public void widgetSelected(SelectionEvent e) {
 				openCommentTemplatesPreferencePage();
 			}
@@ -604,7 +619,8 @@ public class CommitCommentArea extends DialogArea {
         return fComposite;
     }
     
-    protected void firePropertyChangeChange(String property, Object oldValue, Object newValue) {
+    @Override
+	protected void firePropertyChangeChange(String property, Object oldValue, Object newValue) {
         super.firePropertyChangeChange(property, oldValue, newValue);
     }
     
