@@ -36,7 +36,8 @@ import org.eclipse.team.internal.ccvs.core.client.Command.LocalOption;
 import org.eclipse.team.internal.ccvs.core.resources.CVSWorkspaceRoot;
 import org.eclipse.team.internal.ccvs.core.resources.EclipseSynchronizer;
 import org.eclipse.team.internal.ccvs.core.syncinfo.ResourceSyncInfo;
-import org.eclipse.team.internal.ccvs.ui.*;
+import org.eclipse.team.internal.ccvs.ui.CVSUIMessages;
+import org.eclipse.team.internal.ccvs.ui.CVSUIPlugin;
 import org.eclipse.team.internal.ccvs.ui.Policy;
 import org.eclipse.team.internal.ccvs.ui.operations.*;
 import org.eclipse.team.internal.ui.TeamUIPlugin;
@@ -64,6 +65,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 	/* (non-Javadoc)
 	 * @see org.eclipse.team.ui.TeamOperation#shouldRun()
 	 */
+	@Override
 	public boolean shouldRun() {
 		return promptIfNeeded();
 	}
@@ -76,6 +78,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 	 * @param monitor a progress monitor
 	 * @throws InvocationTargetException
 	 */
+	@Override
 	protected void run(final Map projectSyncInfos, final IProject project,
 			IProgressMonitor monitor) throws InvocationTargetException {
 		try {
@@ -93,16 +96,11 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 			// Pass the scheduling rule to the synchronizer so that sync change
 			// events and cache commits to disk are batched
 			EclipseSynchronizer.getInstance().run(getUpdateRule(manager),
-					new ICVSRunnable() {
-						public void run(IProgressMonitor monitor)
-								throws CVSException {
-							try {
-								runWithProjectRule(project,
-										(SyncInfoSet) projectSyncInfos
-												.get(project), monitor);
-							} catch (TeamException e) {
-								throw CVSException.wrapException(e);
-							}
+					monitor1 -> {
+						try {
+							runWithProjectRule(project, (SyncInfoSet) projectSyncInfos.get(project), monitor1);
+						} catch (TeamException e) {
+							throw CVSException.wrapException(e);
 						}
 					}, Policy.subMonitorFor(monitor, 100));
 		} catch (TeamException e) {
@@ -132,6 +130,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 	/* (non-Javadoc)
 	 * @see org.eclipse.team.internal.ccvs.ui.subscriber.CVSSubscriberOperation#run(org.eclipse.core.runtime.IProgressMonitor)
 	 */
+	@Override
 	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
 		skipped.clear();
 		super.run(monitor);
@@ -145,6 +144,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 	/* (non-Javadoc)
 	 * @see org.eclipse.team.internal.ccvs.ui.subscriber.CVSSubscriberAction#run(org.eclipse.team.ui.sync.SyncInfoSet, org.eclipse.core.runtime.IProgressMonitor)
 	 */
+	@Override
 	public void runWithProjectRule(IProject project, SyncInfoSet syncSet, IProgressMonitor monitor) throws TeamException {
 		try {
 			monitor.beginTask(null, 100);
@@ -158,6 +158,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 			
 			// Remove all failed conflicts from the original sync set
 			syncSet.rejectNodes(new FastSyncInfoFilter() {
+				@Override
 				public boolean select(SyncInfo info) {
 					return skipped.getSyncInfo(info.getLocal()) != null;
 				}
@@ -321,6 +322,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 			new AndSyncInfoFilter(new FastSyncInfoFilter[] {
 				FastSyncInfoFilter.getDirectionAndChangeFilter(SyncInfo.CONFLICTING, SyncInfo.ADDITION),
 				new FastSyncInfoFilter() {
+					@Override
 					public boolean select(SyncInfo info) {
 						return info.getLocal().getType() == IResource.FILE;
 					}
@@ -331,6 +333,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 			new AndSyncInfoFilter(new FastSyncInfoFilter[] {
 				FastSyncInfoFilter.getDirectionAndChangeFilter(SyncInfo.CONFLICTING, SyncInfo.CHANGE),
 				new FastSyncInfoFilter() {
+					@Override
 					public boolean select(SyncInfo info) {
 						if (info.getLocal().getType() == IResource.FILE) {
 							try {
@@ -350,6 +353,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 			new AndSyncInfoFilter(new FastSyncInfoFilter[] {
 				FastSyncInfoFilter.getDirectionAndChangeFilter(SyncInfo.CONFLICTING, SyncInfo.CHANGE),
 				new FastSyncInfoFilter() {
+					@Override
 					public boolean select(SyncInfo info) {
 						IResourceVariant remote = info.getRemote();
 						IResourceVariant base = info.getBase();
@@ -368,6 +372,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 			new AndSyncInfoFilter(new FastSyncInfoFilter[] {
 				FastSyncInfoFilter.getDirectionAndChangeFilter(SyncInfo.CONFLICTING, SyncInfo.CHANGE),
 				new FastSyncInfoFilter() {
+					@Override
 					public boolean select(SyncInfo info) {
 						IResource local = info.getLocal();
 						if (local.getType() == IResource.FILE) {
@@ -398,13 +403,10 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 	 * Note: This method is designed to be overridden by test cases.
 	 */
 	protected void warnAboutFailedResources(final SyncInfoSet syncSet) {
-		TeamUIPlugin.getStandardDisplay().syncExec(new Runnable() {
-			public void run() {
-				MessageDialog.openInformation(getShell(), 
-								CVSUIMessages.SafeUpdateAction_warnFilesWithConflictsTitle, 
-								CVSUIMessages.SafeUpdateAction_warnFilesWithConflictsDescription); 
-			}
-		});
+		TeamUIPlugin.getStandardDisplay()
+				.syncExec(() -> MessageDialog.openInformation(getShell(),
+						CVSUIMessages.SafeUpdateAction_warnFilesWithConflictsTitle,
+						CVSUIMessages.SafeUpdateAction_warnFilesWithConflictsDescription));
 	}
 	
 	/**
@@ -453,6 +455,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 		}
 	}
 	
+	@Override
 	protected String getErrorTitle() {
 		return CVSUIMessages.UpdateAction_update; 
 	}
@@ -460,6 +463,7 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 	/* (non-Javadoc)
 	 * @see org.eclipse.team.internal.ccvs.ui.subscriber.CVSSubscriberAction#getJobName(org.eclipse.team.ui.sync.SyncInfoSet)
 	 */
+	@Override
 	protected String getJobName() {
 		SyncInfoSet syncSet = getSyncInfoSet();
 		return NLS.bind(CVSUIMessages.UpdateAction_jobName, new String[] { Integer.valueOf(syncSet.size()).toString() }); 
@@ -477,12 +481,14 @@ public abstract class SafeUpdateOperation extends CVSSubscriberOperation {
 		final SyncInfoSet set = getSyncInfoSet();
 		final boolean[] result = new boolean[] {true};
 		if(getPromptBeforeUpdate()) {
-			TeamUIPlugin.getStandardDisplay().syncExec(new Runnable() {
-				public void run() {
-					String sizeString = Integer.toString(set.size());
-					String message = set.size() > 1 ? NLS.bind(CVSUIMessages.UpdateAction_promptForUpdateSeveral, new String[] { sizeString }) : NLS.bind(CVSUIMessages.UpdateAction_promptForUpdateOne, new String[] { sizeString }); // 
-					result[0] = MessageDialog.openQuestion(getShell(), NLS.bind(CVSUIMessages.UpdateAction_promptForUpdateTitle, new String[] { sizeString }), message); 					 
-				}
+			TeamUIPlugin.getStandardDisplay().syncExec(() -> {
+				String sizeString = Integer.toString(set.size());
+				String message = set.size() > 1
+						? NLS.bind(CVSUIMessages.UpdateAction_promptForUpdateSeveral, new String[] { sizeString })
+						: NLS.bind(CVSUIMessages.UpdateAction_promptForUpdateOne, new String[] { sizeString }); //
+				result[0] = MessageDialog.openQuestion(getShell(),
+						NLS.bind(CVSUIMessages.UpdateAction_promptForUpdateTitle, new String[] { sizeString }),
+						message);
 			});
 		}
 		return result[0];
