@@ -20,9 +20,9 @@ import java.util.*;
 
 import org.eclipse.compare.*;
 import org.eclipse.core.resources.*;
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.Path;
 import org.eclipse.jface.dialogs.Dialog;
-import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.viewers.*;
 import org.eclipse.osgi.util.NLS;
@@ -74,23 +74,29 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 			this.file= file;
 			this.logEntry = logEntry;
 		}
+		@Override
 		public InputStream getContents() throws CoreException {
 			IStorage s = getStorageFromLogEntry(logEntry);
 			if (s == null) return null;
 			return new BufferedInputStream(s.getContents());
 		}
+		@Override
 		public String getName() {
 			return file.getName();
 		}
+		@Override
 		public String getType() {
 			return file.getFileExtension();
 		}
+		@Override
 		public Image getImage() {
 			return CompareUI.getImage(file);
 		}
+		@Override
 		public long getModificationDate() {
 			return logEntry.getDate().getTime();
 		}
+		@Override
 		public String getCharset() throws CoreException {
 			IStorage s = getStorageFromLogEntry(logEntry);
 			if (s instanceof IEncodedStorage) {
@@ -118,6 +124,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 	/**
 	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
 	 */
+	@Override
 	public void createControl(Composite parent) {
 		Composite composite= createComposite(parent, 1, false);
 		setControl(composite);
@@ -151,6 +158,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 		
 		// Bottom: File content viewer
 		fileContentPane = new CompareViewerSwitchingPane(vsplitter, SWT.BORDER | SWT.FLAT) {
+			@Override
 			protected Viewer getViewer(Viewer oldViewer, Object input) {
 				return CompareUI.findContentViewer(oldViewer, input, this, null);
 			}
@@ -166,19 +174,23 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 	protected CheckboxTableViewer createRevisionSelectionTable(CompareViewerPane composite, HistoryTableProvider tableProvider) {
 		CheckboxTableViewer table = tableProvider.createCheckBoxTable(composite);
 		table.setContentProvider(new IStructuredContentProvider() {
+			@Override
 			public Object[] getElements(Object inputElement) {
 				ILogEntry[] entries = getSelectedEntries();
 				if (entries != null) return entries;
 				return new Object[0];
 			}
+			@Override
 			public void dispose() {
 			}
+			@Override
 			public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
 			}
 		});
 		table.setInput(this);
 		table.getTable().addSelectionListener(
 			new SelectionAdapter() {
+				@Override
 				public void widgetSelected(SelectionEvent e) {
 					// Handle check selection in the check state listener
 					if (e.detail == SWT.CHECK) return;
@@ -186,11 +198,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 				}
 			}
 		);
-		table.addCheckStateListener(new ICheckStateListener() {
-			public void checkStateChanged(CheckStateChangedEvent event) {
-				handleRevisionChecked(event);
-			}
-		});
+		table.addCheckStateListener(event -> handleRevisionChecked(event));
 		composite.setContent(table.getControl());
 		return table;
 	}
@@ -202,6 +210,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 		tree.setLabelProvider(
 			new DecoratingLabelProvider(
 				new WorkbenchLabelProvider() {
+					@Override
 					protected String decorateText(String input, Object element) {
 						String text;
 						if (element instanceof IFolder && element.equals(folder)) {
@@ -222,11 +231,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 		
 		GridData data = new GridData(GridData.FILL_BOTH | GridData.GRAB_VERTICAL);
 		tree.getTree().setLayoutData(data);
-		tree.addPostSelectionChangedListener(new ISelectionChangedListener() {
-			public void selectionChanged(SelectionChangedEvent event) {
-				handleFileSelection(event);
-			}
-		});
+		tree.addPostSelectionChangedListener(event -> handleFileSelection(event));
 		composite.setContent(tree.getControl());
 		return tree;
 	}
@@ -400,16 +405,14 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 				final ICVSRemoteFile remoteFile = location.getRemoteFile(new Path(null, info.getRepository()).append(file.getName()).toString(), CVSTag.DEFAULT);
 				
 				// Then we need to fetch the log entries
-				getContainer().run(true, true, new IRunnableWithProgress() {
-					public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-						try {
-							// fetch the entries
-							ILogEntry[] entries = remoteFile.getLogEntries(monitor);
-							// cache the entries with the selected file
-							entriesCache.put(selectedFile, entries);
-						} catch (TeamException e) {
-							throw new InvocationTargetException(e);
-						}
+				getContainer().run(true, true, monitor -> {
+					try {
+						// fetch the entries
+						ILogEntry[] entries = remoteFile.getLogEntries(monitor);
+						// cache the entries with the selected file
+						entriesCache.put(selectedFile, entries);
+					} catch (TeamException e) {
+						throw new InvocationTargetException(e);
 					}
 				});
 			} catch (CVSException e) {
@@ -438,14 +441,12 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 	private IStorage getStorageFromLogEntry(final ILogEntry logEntry) {
 		final IStorage[] s = new IStorage[] { null };
 		try {
-			getContainer().run(true, true, new IRunnableWithProgress() {
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					try {
-						ICVSRemoteFile remoteFile = logEntry.getRemoteFile();
-						s[0] = ((IResourceVariant)remoteFile).getStorage(monitor);
-					} catch (TeamException e) {
-						throw new InvocationTargetException(e);
-					}
+			getContainer().run(true, true, monitor -> {
+				try {
+					ICVSRemoteFile remoteFile = logEntry.getRemoteFile();
+					s[0] = ((IResourceVariant) remoteFile).getStorage(monitor);
+				} catch (TeamException e) {
+					throw new InvocationTargetException(e);
 				}
 			});
 		} catch (InvocationTargetException e) {
@@ -506,23 +507,22 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 	
 	public boolean restoreSelectedFiles() {
 		try {
-			getContainer().run(true, true, new IRunnableWithProgress() {
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					try {
-						monitor.beginTask(null, 100 * filesToRestore.size());
-						for (Iterator iter = filesToRestore.keySet().iterator();iter.hasNext();) {
-							IFile file = (IFile) iter.next();
-							ILogEntry entry = (ILogEntry)filesToRestore.get(file);
-							ensureParentExists(file);
-							file.create(entry.getRemoteFile().getContents(Policy.subMonitorFor(monitor, 50)), false, Policy.subMonitorFor(monitor, 50));
-						}
-					} catch (TeamException e) {
-						throw new InvocationTargetException(e);
-					} catch (CoreException e) {
-						throw new InvocationTargetException(e);
-					} finally {
-						monitor.done();
+			getContainer().run(true, true, monitor -> {
+				try {
+					monitor.beginTask(null, 100 * filesToRestore.size());
+					for (Iterator iter = filesToRestore.keySet().iterator(); iter.hasNext();) {
+						IFile file = (IFile) iter.next();
+						ILogEntry entry = (ILogEntry) filesToRestore.get(file);
+						ensureParentExists(file);
+						file.create(entry.getRemoteFile().getContents(Policy.subMonitorFor(monitor, 50)), false,
+								Policy.subMonitorFor(monitor, 50));
 					}
+				} catch (TeamException e1) {
+					throw new InvocationTargetException(e1);
+				} catch (CoreException e2) {
+					throw new InvocationTargetException(e2);
+				} finally {
+					monitor.done();
 				}
 			});
 		} catch (InvocationTargetException e) {
